MOVE usr %LIBRARY_PREFIX%\
MOVE etc %LIBRARY_PREFIX%\
MOVE cmd\git.exe %LIBRARY_PREFIX%\bin\git.exe
MOVE mingw%ARCH% %LIBRARY_PREFIX%\



rem cd %LIBRARY_PREFIX%
rem call post-install.bat
rem del git_bash.exe
rem del git_cmd.exe
rem del README.portable
rem del post-install.bat

rem IF NOT EXIST %PREFIX%\Menu mkdir %PREFIX%\Menu
rem copy %RECIPE_DIR%\menu-windows.json %PREFIX%\Menu\
rem copy %RECIPE_DIR%\git-for-windows.ico %PREFIX%\Menu\

rem echo export PATH=$(cygpath -a %PREFIX:\=/%)/Library/bin:$PATH >> %LIBRARY_PREFIX%\etc\profile.d\env.sh
rem echo. >> %LIBRARY_PREFIX%\etc\profile.d\env.sh
